::: beignet.add_physicists_hermite_polynomial
::: beignet.differentiate_physicists_hermite_polynomial
::: beignet.divide_physicists_hermite_polynomial
::: beignet.evaluate_physicists_hermite_polynomial
::: beignet.evaluate_physicists_hermite_polynomial_2d
::: beignet.evaluate_physicists_hermite_polynomial_3d
::: beignet.evaluate_physicists_hermite_polynomial_cartesian_2d
::: beignet.evaluate_physicists_hermite_polynomial_cartesian_3d
::: beignet.fit_physicists_hermite_polynomial
::: beignet.integrate_physicists_hermite_polynomial
::: beignet.linear_physicists_hermite_polynomial
::: beignet.multiply_physicists_hermite_polynomial
::: beignet.multiply_physicists_hermite_polynomial_by_x
::: beignet.physicists_hermite_polynomial_companion
::: beignet.physicists_hermite_polynomial_domain
::: beignet.physicists_hermite_polynomial_from_roots
::: beignet.physicists_hermite_polynomial_one
::: beignet.physicists_hermite_polynomial_power
::: beignet.physicists_hermite_polynomial_roots
::: beignet.physicists_hermite_polynomial_to_polynomial
::: beignet.physicists_hermite_polynomial_vandermonde
::: beignet.physicists_hermite_polynomial_vandermonde_2d
::: beignet.physicists_hermite_polynomial_vandermonde_3d
::: beignet.physicists_hermite_polynomial_weight
::: beignet.physicists_hermite_polynomial_x
::: beignet.physicists_hermite_polynomial_zero
::: beignet.subtract_physicists_hermite_polynomial
::: beignet.trim_physicists_hermite_polynomial_coefficients
